@@ -1,4 +1,5 @@
 from obapi.models.classifiers import (
+    CLASSIFIER_SLUG_MAX_LENGTH,
     Author,
     AuthorAlias,
     ExternalLink,
@@ -18,9 +19,16 @@ from obapi.models.content import (
     VideoContentItem,
     YoutubeContentItem,
 )
-from obapi.models.sequence import Sequence, SequenceMember
+from obapi.models.sequence import (
+    SEQUENCE_SLUG_MAX_LENGTH,
+    BaseSequence,
+    BaseSequenceMember,
+    Sequence,
+    SequenceMember,
+)
 
 __all__ = [
+    "CLASSIFIER_SLUG_MAX_LENGTH",
     "Author",
     "Idea",
     "Topic",
@@ -37,6 +45,9 @@ __all__ = [
     "SpotifyContentItem",
     "TextContentItem",
     "OBContentItem",
+    "SEQUENCE_SLUG_MAX_LENGTH",
+    "BaseSequence",
+    "BaseSequenceMember",
     "Sequence",
     "SequenceMember",
 ]
