@@ -2,7 +2,7 @@ import datetime
 import re
 
 import bleach
-from slugify import slugify
+import slugify
 
 ISO_8601_DURATION_PATTERN = re.compile(
     (
@@ -24,12 +24,18 @@ def parse_duration(duration):
 
 
 def plaintext_to_html(text):
-    # Convert line breaks to <br> elements
-    broken_text = text.replace("\n", "<br>")
-
-    # Linkify URLs and email addresses
-    return bleach.linkify(broken_text, parse_email=True)
+    """Clean and format plaintext, outputting HTML."""
+    clean_text = bleach.clean(text)
+    html_text = f"<pre>{clean_text}</pre>"
+    linkified_text = bleach.linkify(html_text, parse_email=True)
+    return linkified_text
 
 
-def to_slug(text):
-    return slugify(text)
+def to_slug(text, max_length):
+    return slugify.slugify(text, max_length=max_length)
+
+
+def chunk_iterator(seq, chunk_size):
+    """An iterator which yields chunks of size `chunk_size` of a sequence `seq`."""
+    for i in range(0, len(seq), chunk_size):
+        yield seq[i : i + chunk_size]
